Skip to contents

Perform an simple keyword search of the Internet Archive.

Usage

ia_keyword_search(keywords, num_results = 5, page = 1, print_total = TRUE)

Arguments

keywords

The keywords to search for.

num_results

The number of results to return per page.

page

When results are paged, which page of results to return.

print_total

Should the total number of results for this query be printed as a message?

Value

A character vector of Internet Archive item IDs.

Examples

ia_keyword_search("isaac hecker", num_results = 20)
#> 82 total items found. This query requested 20 results.
#>  [1] "fatherheckerhisf0000mcso_b6n1"                 
#>  [2] "questionsofsoul00heck"                         
#>  [3] "prophetsguardian0000cumm"                      
#>  [4] "heckerstudiesess0000unse"                      
#>  [5] "fav-isaac_potter"                              
#>  [6] "lifeoffatherheck01elli"                        
#>  [7] "catholicchurchi00heckgoog"                     
#>  [8] "B-001-035-841-ALL"                             
#>  [9] "youngconvertsorm00smal"                        
#> [10] "questionssoul00heckgoog"                       
#> [11] "a587173700heckuoft"                            
#> [12] "catholicworld01unkngoog"                       
#> [13] "a589111500unknuoft"                            
#> [14] "isaacthomashecke0000behn"                      
#> [15] "catholicintellec0000rehe"                      
#> [16] "life-and-doctrines-of-saint-catherine-of-genoa"
#> [17] "bwb_T5-BCL-008"                                
#> [18] "yankeepaulisaact0000hold_r0b9"                 
#> [19] "unset0003unse_y5b3"                            
#> [20] "theologyinameric0000holi"