Perform an simple keyword search of the Internet Archive.
Source:R/ia_keyword_search.R
ia_keyword_search.RdPerform an simple keyword search of the Internet Archive.
Examples
ia_keyword_search("isaac hecker", num_results = 20)
#> 80 total items found. This query requested 20 results.
#> [1] "bwb_T5-BCL-008" "youngconvertsorm00smal"
#> [3] "heckerstudiesess0000unse" "a589111500unknuoft"
#> [5] "fatherhecker00sedggoog" "catholicchurchi00heckgoog"
#> [7] "germansongspopul0000unse" "fatherhecker01sedg"
#> [9] "fatherheckerhisf0000mcso" "catholicworld00projgoog"
#> [11] "QuestionsOfTheSoul" "catholicworld01projgoog"
#> [13] "abitunpublished00heckgoog" "questionssoul01heckgoog"
#> [15] "aspirationsofnat00heck_2" "aspirationsofnat00heck_1"
#> [17] "aspirationsofnat00heckuoft" "americanpersonal0000unse"
#> [19] "yankeepaulisaact0000hold" "americancatholic0000unse_x6i3"