Skip to contents

Perform an simple keyword search of the Internet Archive.

Usage

ia_keyword_search(keywords, num_results = 5, page = 1, print_total = TRUE)

Arguments

keywords

The keywords to search for.

num_results

The number of results to return per page.

page

When results are paged, which page of results to return.

print_total

Should the total number of results for this query be printed as a message?

Value

A character vector of Internet Archive item IDs.

Examples

ia_keyword_search("isaac hecker", num_results = 20)
#> 80 total items found. This query requested 20 results.
#>  [1] "isaacthomashecke0000behn"                               
#>  [2] "cu31924031386414"                                       
#>  [3] "theologyinameric0000holi"                               
#>  [4] "lepereheckerfond0000elli"                               
#>  [5] "a589111500unknuoft"                                     
#>  [6] "catholicworld01projgoog"                                
#>  [7] "celestialhomespu0000kath"                               
#>  [8] "cu31924029381013"                                       
#>  [9] "lifeoffatherheck1972elli"                               
#> [10] "fatherhecker00sedggoog"                                 
#> [11] "TheLifeOfFatherHecker"                                  
#> [12] "isaactheckerdiar0000heck_k1j2"                          
#> [13] "catholicworld00projgoog"                                
#> [14] "isaactheckerdiar0000heck"                               
#> [15] "cia-readingroom-document-cia-rdp96-00788r001200340011-1"
#> [16] "roadstoromeanteb0000fran"                               
#> [17] "questionssoul01heckgoog"                                
#> [18] "bwb_T5-BCL-008"                                         
#> [19] "paulistfatherisa0000hanl"                               
#> [20] "yankeepaulisaact0000hold"