Perform an simple keyword search of the Internet Archive.
Source:R/ia_keyword_search.R
ia_keyword_search.RdPerform an simple keyword search of the Internet Archive.
Examples
ia_keyword_search("isaac hecker", num_results = 20)
#> 80 total items found. This query requested 20 results.
#> [1] "isaacthomashecke0000behn"
#> [2] "cu31924031386414"
#> [3] "theologyinameric0000holi"
#> [4] "lepereheckerfond0000elli"
#> [5] "a589111500unknuoft"
#> [6] "catholicworld01projgoog"
#> [7] "celestialhomespu0000kath"
#> [8] "cu31924029381013"
#> [9] "lifeoffatherheck1972elli"
#> [10] "fatherhecker00sedggoog"
#> [11] "TheLifeOfFatherHecker"
#> [12] "isaactheckerdiar0000heck_k1j2"
#> [13] "catholicworld00projgoog"
#> [14] "isaactheckerdiar0000heck"
#> [15] "cia-readingroom-document-cia-rdp96-00788r001200340011-1"
#> [16] "roadstoromeanteb0000fran"
#> [17] "questionssoul01heckgoog"
#> [18] "bwb_T5-BCL-008"
#> [19] "paulistfatherisa0000hanl"
#> [20] "yankeepaulisaact0000hold"