Skip to contents

Perform an simple keyword search of the Internet Archive.

Usage

ia_keyword_search(keywords, num_results = 5, page = 1, print_total = TRUE)

Arguments

keywords

The keywords to search for.

num_results

The number of results to return per page.

page

When results are paged, which page of results to return.

print_total

Should the total number of results for this query be printed as a message?

Value

A character vector of Internet Archive item IDs.

Examples

ia_keyword_search("isaac hecker", num_results = 20)
#> 80 total items found. This query requested 20 results.
#>  [1] "publiccharities00heck"                           
#>  [2] "bwb_T5-BCL-008"                                  
#>  [3] "catholicchurchi00heckgoog"                       
#>  [4] "questionsofsoul000heck"                          
#>  [5] "underlovetale-an-undertale-dating-sim-game_flash"
#>  [6] "questionssoul00heckgoog"                         
#>  [7] "lepereheckerfond0000elli"                        
#>  [8] "aspirationsofnat00heck_1"                        
#>  [9] "aspirationsofnat00heck"                          
#> [10] "yankeepaulisaact0000hold"                        
#> [11] "catholicintellec0000rehe"                        
#> [12] "catholicworld01unkngoog"                         
#> [13] "9118095.med.yale.edu"                            
#> [14] "questionsofsoul00heck_0"                         
#> [15] "uncatholicismeam00dela"                          
#> [16] "QuestionsOfTheSoul"                              
#> [17] "youngconvertsorm00smal"                          
#> [18] "lifeoffatherheck1972elli"                        
#> [19] "catholicworld02unkngoog"                         
#> [20] "fatherheckerhisf0000mcso_b6n1"