Skip to contents

Perform an simple keyword search of the Internet Archive.

Usage

ia_keyword_search(keywords, num_results = 5, page = 1, print_total = TRUE)

Arguments

keywords

The keywords to search for.

num_results

The number of results to return per page.

page

When results are paged, which page of results to return.

print_total

Should the total number of results for this query be printed as a message?

Value

A character vector of Internet Archive item IDs.

Examples

ia_keyword_search("isaac hecker", num_results = 20)
#> 77 total items found. This query requested 20 results.
#>  [1] "yankeepaulisaact0000unse"                               
#>  [2] "unboundedframefr0000fell"                               
#>  [3] "lifeoffatherheck0000elli"                               
#>  [4] "ramon-2025-live"                                        
#>  [5] "somethingaboutau0003unse_a9h9"                          
#>  [6] "livingreligions0009fish"                                
#>  [7] "brownsonheckerco0000brow"                               
#>  [8] "fatherheckerhisf0000mcso_b6n1"                          
#>  [9] "cia-readingroom-document-cia-rdp96-00788r001200340011-1"
#> [10] "celestialhomespu0000burt"                               
#> [11] "roadstoromeanteb0000fran"                               
#> [12] "catholicworld01projgoog"                                
#> [13] "the-secret-to-self-motivation"                          
#> [14] "youngconvertsorm00smal"                                 
#> [15] "fatherheckerhisf0000mcso"                               
#> [16] "germansongspopul0000unse"                               
#> [17] "9118095.med.yale.edu"                                   
#> [18] "fav-isaac_potter"                                       
#> [19] "isaacheckerameri0000obri"                               
#> [20] "lepreheckerfond00elligoog"