Access the item metadata from an Internet Archive item
Value
A data frame containing the metadata, with columns id for the
item identifier, field for the name of the metadata field, and
value for the metadata values.
Examples
ats_query <- c("publisher" = "american tract society")
ids <- ia_search(ats_query, num_results = 3)
#> 1535 total items found. This query requested 3 results.
items <- ia_get_items(ids)
#> Getting treatiseonell00edwa
#> Getting whenblindsaw00burr
#> Getting wewouldseejesus00socigoog
metadata <- ia_metadata(items)
#> Warning: `data_frame()` was deprecated in tibble 1.1.0.
#> ℹ Please use `tibble()` instead.
#> ℹ The deprecated feature was likely used in the internetarchive package.
#> Please report the issue at
#> <https://github.com/ropensci/internetarchive/issues>.
metadata
#> # A tibble: 123 × 3
#> id field value
#> <chr> <chr> <chr>
#> 1 treatiseonell00edwa title The treatise on religious af…
#> 2 treatiseonell00edwa creator1 Edwards, Jonathan, 1703-1758
#> 3 treatiseonell00edwa creator2 Ellerby, W
#> 4 treatiseonell00edwa subject Emotions
#> 5 treatiseonell00edwa publisher New York, American Tract Soc…
#> 6 treatiseonell00edwa date 1833
#> 7 treatiseonell00edwa language eng
#> 8 treatiseonell00edwa copyright-evidence-operator rebecca.m
#> 9 treatiseonell00edwa possible-copyright-status NOT_IN_COPYRIGHT
#> 10 treatiseonell00edwa copyright-region US
#> # ℹ 113 more rows