Access the item metadata from an Internet Archive item
Value
A data frame containing the metadata, with columns id for the
item identifier, field for the name of the metadata field, and
value for the metadata values.
Examples
ats_query <- c("publisher" = "american tract society")
ids <- ia_search(ats_query, num_results = 3)
#> 1530 total items found. This query requested 3 results.
items <- ia_get_items(ids)
#> Getting bearingofarchaeo0000geor
#> Getting buildingchurch0000matt_x3m1
#> Getting saintandhissavi03spurgoog
metadata <- ia_metadata(items)
#> Warning: `data_frame()` was deprecated in tibble 1.1.0.
#> ℹ Please use `tibble()` instead.
#> ℹ The deprecated feature was likely used in the internetarchive package.
#> Please report the issue at
#> <https://github.com/ropensci/internetarchive/issues>.
metadata
#> # A tibble: 135 × 3
#> id field value
#> <chr> <chr> <chr>
#> 1 bearingofarchaeo0000geor identifier bearingofarchaeo0000geor
#> 2 bearingofarchaeo0000geor boxid IA41437606
#> 3 bearingofarchaeo0000geor camera USB PTP Class Camera
#> 4 bearingofarchaeo0000geor collection1 internetarchivebooks
#> 5 bearingofarchaeo0000geor collection2 printdisabled
#> 6 bearingofarchaeo0000geor collection3 inlibrary
#> 7 bearingofarchaeo0000geor contributor Internet Archive
#> 8 bearingofarchaeo0000geor creator George L Robinson
#> 9 bearingofarchaeo0000geor date 1941-01-01
#> 10 bearingofarchaeo0000geor language eng
#> # ℹ 125 more rows