Skip to contents

Access the item metadata from an Internet Archive item

Usage

ia_metadata(items)

Arguments

items

A list object describing an Internet Archive items returned from the API.

Value

A data frame containing the metadata, with columns id for the item identifier, field for the name of the metadata field, and value for the metadata values.

Examples

ats_query <- c("publisher" = "american tract society")
ids       <- ia_search(ats_query, num_results = 3)
#> 1511 total items found. This query requested 3 results.
items     <- ia_get_items(ids)
#> Getting fromoceantoocean00shilrich
#> Getting MN41554ucmf_9
#> Getting fromhongkongtoh00clargoog
metadata  <- ia_metadata(items)
#> Warning: `data_frame()` was deprecated in tibble 1.1.0.
#>  Please use `tibble()` instead.
#>  The deprecated feature was likely used in the internetarchive package.
#>   Please report the issue at
#>   <https://github.com/ropensci/internetarchive/issues>.
metadata
#> # A tibble: 105 × 3
#>    id                         field                       value                 
#>    <chr>                      <chr>                       <chr>                 
#>  1 fromoceantoocean00shilrich title                       From ocean to ocean :…
#>  2 fromoceantoocean00shilrich creator                     Shiland, Andrew, 1820…
#>  3 fromoceantoocean00shilrich subject1                    Overland journeys to …
#>  4 fromoceantoocean00shilrich subject2                    West (U.S.) -- Descri…
#>  5 fromoceantoocean00shilrich publisher                   New York : American T…
#>  6 fromoceantoocean00shilrich date                        1892                  
#>  7 fromoceantoocean00shilrich language                    eng                   
#>  8 fromoceantoocean00shilrich copyright-evidence-operator ian frederick-rothwell
#>  9 fromoceantoocean00shilrich possible-copyright-status   NOT_IN_COPYRIGHT      
#> 10 fromoceantoocean00shilrich copyright-region            US                    
#> # ℹ 95 more rows