Skip to contents

Access the item metadata from an Internet Archive item

Usage

ia_metadata(items)

Arguments

items

A list object describing an Internet Archive items returned from the API.

Value

A data frame containing the metadata, with columns id for the item identifier, field for the name of the metadata field, and value for the metadata values.

Examples

ats_query <- c("publisher" = "american tract society")
ids       <- ia_search(ats_query, num_results = 3)
#> 1494 total items found. This query requested 3 results.
items     <- ia_get_items(ids)
#> Getting ladyhuntingtonhe00knigiala
#> Getting janetaylor00knig
#> Getting 101214593.nlm.nih.gov
metadata  <- ia_metadata(items)
#> Warning: `data_frame()` was deprecated in tibble 1.1.0.
#>  Please use `tibble()` instead.
#>  The deprecated feature was likely used in the internetarchive package.
#>   Please report the issue at
#>   <https://github.com/ropensci/internetarchive/issues>.
metadata
#> # A tibble: 131 × 3
#>    id                         field                       value                 
#>    <chr>                      <chr>                       <chr>                 
#>  1 ladyhuntingtonhe00knigiala title                       Lady Huntington and h…
#>  2 ladyhuntingtonhe00knigiala creator                     Knight, Helen (Cross)…
#>  3 ladyhuntingtonhe00knigiala subject                     Huntingdon, Selina Ha…
#>  4 ladyhuntingtonhe00knigiala publisher                   New York : American t…
#>  5 ladyhuntingtonhe00knigiala date                        [c1853]               
#>  6 ladyhuntingtonhe00knigiala language                    eng                   
#>  7 ladyhuntingtonhe00knigiala copyright-evidence-operator alyson-wieczorek      
#>  8 ladyhuntingtonhe00knigiala possible-copyright-status   NOT_IN_COPYRIGHT      
#>  9 ladyhuntingtonhe00knigiala copyright-region            US                    
#> 10 ladyhuntingtonhe00knigiala copyright-evidence          Evidence reported by …
#> # ℹ 121 more rows